import useTeamStateValidator from '@/instructor/InstructorTeamSelector/useTeamStateValidator'
import {
  Button,
  CheckboxCard,
  NonIdealState,
  Section,
  SectionCard,
} from '@blueprintjs/core'
import { toggleTeam, unsetTeams, useTeams } from '../vars/teams'

const InstructorTeams = () => {
  const teamsVar = useTeams()
  const validator = useTeamStateValidator()

  return (
    <Section
      title={'Instructor Subscribed Teams'}
      subtitle={`Current amount of synchronized teams: ${
        Object.keys(teamsVar).length
      }`}
      rightElement={
        <div
          style={{
            display: 'flex',
            margin: '0.5rem',
            flexDirection: 'column',
            gap: '0.25rem',
            alignItems: 'center',
          }}
        >
          <Button
            fill
            onClick={() => {
              validator()
            }}
          >
            Revalidate subscribed teams
          </Button>
          <Button
            fill
            onClick={() => {
              unsetTeams()
            }}
          >
            Unset subscribed teams
          </Button>
        </div>
      }
    >
      <SectionCard>
        {Object.keys(teamsVar).length === 0 && (
          <div style={{ padding: '1rem' }}>
            <NonIdealState
              icon='low-voltage-pole'
              description='Currently there are no active teams to manage'
            />
          </div>
        )}
        {Object.keys(teamsVar).length > 0 && (
          <div style={{ padding: '0.25rem' }}>
            {Object.entries(teamsVar).map(([key, team]) => (
              <CheckboxCard
                key={key}
                checked={team.show}
                onClick={e => {
                  e.preventDefault()
                  toggleTeam(key)
                }}
              >
                <span>{team.teamRole || `Team ${team.teamId}`}</span>
              </CheckboxCard>
            ))}
          </div>
        )}
      </SectionCard>
    </Section>
  )
}

export default InstructorTeams
