import type { LinkButtonProps } from '@/components/LinkButton'
import LinkButton from '@/components/LinkButton'
import { css } from '@emotion/css'
import { useAuthIdentity } from '@inject/graphql/auth'
import NotificationDropdown from '@inject/shared/notification/NotificationDropdown'
import { useMemo } from 'react'

const float = css`
  position: fixed;
  bottom: 0;
  right: 0;
  left: 0;
`

const navbar = css`
  width: max-content;
  max-width: 100vw;
  margin-left: auto;
  flex-grow: 0;
  justify-content: right;
  display: flex;
  gap: 1rem;
  white-space: nowrap;
  padding: 0.5rem;
  background-color: white;
  border: 1px solid rgba(17, 20, 24, 0.15);
  border-right: 0;
  border-bottom: 0;

  @media (max-width: 768px) {
    .bp5-button .bp5-icon {
      margin-right: 0;
    }
    .bp5-button-text {
      display: none;
    }
    border-left: 0;
    justify-content: center;
    width: 100%;
  }

  .bp5-dark & {
    background-color: #2f343c;
    border-color: rgba(255, 255, 255, 0.15);
  }
`

const superuserLinks: LinkButtonProps[] = [
  {
    link: ['/exercise-panel'],
    button: {
      icon: 'torch',
      text: 'Exercise Panel',
      title: 'Exercise Panel',
      minimal: true,
    },
  },
  ...(!import.meta.env.VITE_NOAUTH
    ? ([
        {
          link: ['/users'],
          button: {
            icon: 'people',
            text: 'Users',
            title: 'Users',
            minimal: true,
          },
        },
      ] as LinkButtonProps[])
    : []),
]

const Navbar = () => {
  const { isStaff, isSuperuser } = useAuthIdentity()

  const links: LinkButtonProps[] = useMemo(
    () => [
      {
        link: ['/'],
        button: {
          icon: 'home',
          text: 'Home',
          title: 'Home',
          minimal: true,
        },
      },
      ...((isStaff || isSuperuser) && !import.meta.env.VITE_NOAUTH
        ? superuserLinks
        : []),
      {
        link: ['/settings'],
        button: {
          icon: 'cog',
          text: 'Settings',
          title: 'Settings',
          minimal: true,
        },
      },
    ],
    [isSuperuser]
  )

  return (
    <div className={float}>
      <div className={navbar}>
        {links.map(child => (
          <LinkButton key={child.link[0] as string} {...child} />
        ))}
        <NotificationDropdown placement='top' hideLabel />
      </div>
    </div>
  )
}

export default Navbar
