import useFormatTimestamp from '@/analyst/useFormatTimestamp'
import { HIGHLIGHTED_COLOR } from '@/analyst/utilities'
import FileViewRedirectButton from '@/components/FileViewRedirectButton'
import { Classes, Icon, Section, SectionCard } from '@blueprintjs/core'
import type { Email } from '@inject/graphql/fragments/Email.generated'
import { useWriteReadReceiptEmail } from '@inject/graphql/mutations/clientonly/WriteReadReceiptEmail.generated'
import Timestamp from '@inject/shared/components/Timestamp'
import type { FC } from 'react'
import { useEffect, useState } from 'react'

interface EmailCardProps {
  exerciseId: string
  teamId: string
  email: Email
  inAnalyst?: boolean
  inInstructor?: boolean
}

const EmailCard: FC<EmailCardProps> = ({
  exerciseId,
  teamId,
  email,
  inAnalyst,
  inInstructor,
}) => {
  const formatTimestamp = useFormatTimestamp()

  const [newIndicator, setNewIndicator] = useState(false)
  const [mutate] = useWriteReadReceiptEmail({
    variables: { emailId: email.id },
  })
  useEffect(() => {
    if (!email.readReceipt) {
      mutate()
      setNewIndicator(() => true)
    }
  }, [email.readReceipt, mutate])

  return (
    <Section
      style={{
        background: newIndicator ? HIGHLIGHTED_COLOR : undefined,
        overflow: 'unset',
      }}
      icon={
        email.sender.team?.id === teamId ? (
          <Icon
            className={Classes.TEXT_MUTED}
            icon='send-message'
            title='sent by the selected team'
          />
        ) : (
          <Icon
            className={Classes.TEXT_MUTED}
            icon='envelope'
            title='received by the selected team'
          />
        )
      }
      title={email.sender.address}
      rightElement={
        <span>
          {inAnalyst ? (
            formatTimestamp(email.timestamp)
          ) : (
            <Timestamp minimal datetime={new Date(email.timestamp)} />
          )}
        </span>
      }
    >
      <SectionCard>
        <div
          style={{
            margin: '0em 0em 0em 0em',
            wordWrap: 'break-word',
            whiteSpace: 'pre-wrap',
          }}
          dangerouslySetInnerHTML={{ __html: email.content.rendered }}
        />
        {email.content.fileInfo && (
          <FileViewRedirectButton
            teamId={teamId}
            fileInfo={email.content.fileInfo}
            exerciseId={exerciseId}
            inInstructor={inInstructor}
          />
        )}
      </SectionCard>
    </Section>
  )
}

export default EmailCard
