import useFormatTimestamp from '@/analyst/useFormatTimestamp'
import { HIGHLIGHTED_COLOR, ellipsized } from '@/analyst/utilities'
import { Card, Classes, Icon } from '@blueprintjs/core'
import type { Email } from '@inject/graphql/fragments/Email.generated'
import type { EmailThread } from '@inject/graphql/fragments/EmailThread.generated'
import { useWriteReadReceiptEmailThread } from '@inject/graphql/mutations/clientonly/WriteReadReceiptEmailThread.generated'
import Timestamp from '@inject/shared/components/Timestamp'
import type { FC } from 'react'

interface ThreadLogCardProps {
  emailThread: EmailThread
  lastEmail: Email
  teamId: string
  isSelected?: boolean
  onClick: (e: React.MouseEvent<HTMLDivElement, MouseEvent>) => void
  inAnalyst?: boolean
}

const ThreadLogCard: FC<ThreadLogCardProps> = ({
  emailThread,
  lastEmail,
  teamId,
  isSelected,
  onClick,
  inAnalyst,
}) => {
  const formatTimestamp = useFormatTimestamp()

  const [mutate] = useWriteReadReceiptEmailThread({
    variables: {
      emailThreadId: emailThread.id,
    },
  })

  return (
    <Card
      interactive
      onClick={event => {
        if (!emailThread.readReceipt) {
          mutate()
        }
        onClick(event)
      }}
      style={{
        background: isSelected
          ? 'rgba(45, 114, 210, 0.2)'
          : emailThread.readReceipt === null
            ? HIGHLIGHTED_COLOR
            : undefined,
        display: 'flex',
        justifyContent: 'space-between',
        gap: '5px',
      }}
    >
      <div className={`${Classes.SECTION_HEADER_LEFT} ${ellipsized}`}>
        <div className={ellipsized}>
          <div className={ellipsized}>
            <span
              style={{
                fontWeight: 'normal',
                fontStyle: 'italic',
              }}
            >
              {lastEmail.sender.team?.id === teamId ? 'to: ' : 'from: '}
            </span>
            {lastEmail.sender.team?.id === teamId
              ? emailThread.participants
                  .filter(participant => participant.team?.id !== teamId)
                  .map(participant => participant.address)
                  .join(', ')
              : lastEmail.sender.address}
          </div>
          <h6
            className={`${Classes.HEADING} ${Classes.SECTION_HEADER_TITLE} ${ellipsized}`}
          >
            {lastEmail.content.fileInfo && (
              <Icon
                icon='paperclip'
                className={Classes.TEXT_MUTED}
                style={{ paddingRight: '0.25em' }}
              />
            )}
            {emailThread.subject}
          </h6>
          <div
            className={`${Classes.TEXT_MUTED} ${Classes.SECTION_HEADER_SUB_TITLE} ${ellipsized}`}
          >
            {lastEmail.content.raw}
          </div>
        </div>
      </div>
      <div className={Classes.SECTION_HEADER_RIGHT}>
        <span style={{ whiteSpace: 'nowrap' }}>
          {inAnalyst ? (
            formatTimestamp(lastEmail.timestamp)
          ) : (
            <Timestamp minimal datetime={new Date(lastEmail.timestamp)} />
          )}
        </span>
        <Icon icon='chevron-right' className={Classes.TEXT_MUTED} />
      </div>
    </Card>
  )
}

export default ThreadLogCard
