import { Button } from '@blueprintjs/core'
import { useAuthIdentity } from '@inject/graphql/auth'
import { useHost } from '@inject/graphql/connection/host'
import { useWs } from '@inject/graphql/connection/ws'
import { httpGraphql } from '@inject/shared/config'
import { usePopupContext } from '@inject/shared/popup/PopupContext'
import csrfFetch from '@inject/shared/utils/csrfFetch'
import { Suspense, lazy, useEffect, useState } from 'react'

const GraphiQL = await lazy(() => import('graphiql'))
import('graphiql/graphiql.css')
const { createGraphiQLFetcher } = await import('@graphiql/toolkit')

const GraphiQLPage = /* @__PURE__ */ () => {
  const ws = useWs()
  const host = useHost()
  const { isStaff } = useAuthIdentity()
  const { showPopup } = usePopupContext()
  const [confirmed, setConfirmed] = useState(false)

  const Dialog = () => (
    <div>
      <p>
        You are about to access the GraphiQL interface.
        <br />
        This interface allows you to interact with the backend directly.
        <br />
        <strong>
          Do not use this interface unless you know what you are doing.
        </strong>
      </p>
      <p>
        <strong>Are you sure you want to proceed?</strong>
        <Button fill intent='danger' onClick={() => setConfirmed(true)}>
          Yes
        </Button>
      </p>
    </div>
  )
  useEffect(() => {
    if (!confirmed) {
      showPopup(3, <Dialog />)
    }
  }, [confirmed])
  if (!isStaff || !confirmed) {
    return <p>You are not authorized to access this page</p>
  }

  if (!ws || !host) {
    return <p>No `WS` or `HOST` set to ApolloProviderWrapper</p>
  }

  const http = httpGraphql(host)

  return (
    <Suspense fallback={<p>Loading...</p>}>
      <div style={{ height: 'calc(100vh - 3rem)' }}>
        <GraphiQL
          fetcher={createGraphiQLFetcher({
            url: http,
            subscriptionUrl: ws,
            fetch: csrfFetch,
          })}
        />
      </div>
    </Suspense>
  )
}

export default GraphiQLPage
