import ErrorMessage from '@/components/ErrorMessage'
import { useNavigate } from '@/router'
import {
  Card,
  CardList,
  Classes,
  Elevation,
  NonIdealState,
  Section,
  SectionCard,
} from '@blueprintjs/core'
import { ChevronRight } from '@blueprintjs/icons'
import { css } from '@emotion/css'
import type { Team } from '@inject/graphql/fragments/Team.generated'
import { useGetRunningExercises } from '@inject/graphql/queries/GetRunningExercises.generated'
import ColorBox from '@inject/shared/components/ColorBox'
import notEmpty from '@inject/shared/utils/notEmpty'
import { useMemo } from 'react'
import Reloader from '../Reloader'

const between = css`
  justify-content: space-between;
  gap: 1rem;
`

const TeamSelector = () => {
  const { error, data } = useGetRunningExercises({
    fetchPolicy: 'network-only',
  })
  const nav = useNavigate()

  const exercises = useMemo(
    () => (data?.exercises || []).filter(notEmpty),
    [data]
  )

  if (error) {
    return (
      <ErrorMessage>
        <h1>Error!</h1>
        <p>{error.message}</p>
      </ErrorMessage>
    )
  }

  return (
    <Section
      title='Trainee Team Selection'
      rightElement={<Reloader minimal fill />}
      elevation={Elevation.ONE}
    >
      {exercises.length === 0 && (
        <div style={{ padding: '1rem' }}>
          <NonIdealState
            icon='low-voltage-pole'
            description='There are no exercises active'
          />
        </div>
      )}
      {exercises.filter(notEmpty).map(x => (
        <SectionCard padded key={x.id}>
          <h3 style={{ paddingBottom: '1rem' }}>{`Exercise ${x.id}`}</h3>
          <CardList bordered>
            {x.teams.map((y: Team) => (
              <Card
                interactive
                onClick={() =>
                  nav('/trainee/:exerciseId/:teamId', {
                    params: {
                      exerciseId: x.id,
                      teamId: y.id,
                    },
                  })
                }
                className={between}
                key={y.id}
              >
                <h4>{y.role || y.name}</h4>
                <ColorBox id={Number(y.id)} style={{ marginRight: 'auto' }} />
                <ChevronRight className={Classes.TEXT_MUTED} />
              </Card>
            ))}
          </CardList>
        </SectionCard>
      ))}
    </Section>
  )
}

export default TeamSelector
