import InjectLogo from '@/assets/inject-logo--vertical-black.svg?react'
import StaffSelector from '@/logic/StaffSelector'
import TeamSelector from '@/logic/TeamSelector'
import { useNavigate } from '@/router'
import { useSetPageTitle } from '@/utils'
import { Checkbox, Collapse } from '@blueprintjs/core'
import { useAuthIdentity } from '@inject/graphql/auth'
import Container from '@inject/shared/components/Container'
import { useEffect, useState } from 'react'

const Index = () => {
  useSetPageTitle('Team Selection')
  const { isActive, isStaff, isSuperuser, isLogged, loading } =
    useAuthIdentity()
  const nav = useNavigate()
  useEffect(() => {
    if (!isLogged && !loading) {
      nav('/login')
    }
  }, [isLogged, nav, loading])
  const [enableTrainee, setEnableTrainee] = useState(false)

  return (
    <div
      style={{
        display: 'flex',
        height: '100%',
        flexDirection: 'column',
        justifyContent: 'center',
      }}
    >
      <Container>
        <InjectLogo
          style={{
            width: '210px',
            height: '200px',
            display: 'inline-block',
            float: 'right',
          }}
        />
        <h1>Welcome</h1>
        <p>
          Embark on a journey of strategic crisis management and incident
          response. Our scenarios will enhance your skills and team
          collaboration to boost the resilience of your organization.
        </p>
      </Container>
      <Container>
        {((isActive && !isStaff) || import.meta.env.VITE_NOAUTH) && (
          <>
            <h2>Select your team/role</h2>
            <TeamSelector />
            <br />
          </>
        )}
        {(isStaff || isSuperuser) && !import.meta.env.VITE_NOAUTH && (
          <>
            <h2>Select your administrative role</h2>
            <br />
            <StaffSelector enableRefresh={!enableTrainee} />
            <br />
            <Checkbox
              checked={enableTrainee}
              onChange={e => setEnableTrainee(e.target.checked)}
            >
              Enable trainee exercise list (allows you to enter exercises as a
              trainee for testing purposes)
            </Checkbox>
            <Collapse isOpen={enableTrainee} keepChildrenMounted={false}>
              <br />
              <h2>Trainee Team Selection</h2>
              <TeamSelector />
            </Collapse>
          </>
        )}
      </Container>
    </div>
  )
}

export default Index
