import ToolAction from '@/actionlog/ToolAction'
import type { Section } from '@/components/Sidebar'
import Sidebar from '@/components/Sidebar'
import type { Tool } from '@inject/graphql/fragments/Tool.generated'
import { useGetExerciseConfig } from '@inject/graphql/queries/GetExerciseConfig.generated'
import notEmpty from '@inject/shared/utils/notEmpty'
import type { FC } from 'react'
import { memo, useMemo } from 'react'

const UNDEFINED_ID = 'undefined'

interface ToolbarProps {
  teamId: string
  exerciseId: string
}

const Toolbar: FC<ToolbarProps> = ({ teamId, exerciseId }) => {
  const { data } = useGetExerciseConfig({
    variables: {
      exerciseId,
      teamId,
    },
  })
  const process = (data?.teamTools ?? []).filter(notEmpty)

  const groups = useMemo(() => {
    const map = new Map<string, Tool[]>()

    process.forEach(x => {
      let prefix = x.name.split('_')[0]!

      if (prefix === x.name) {
        prefix = 'Uncategorized'
      }

      if (map.has(prefix)) {
        map.get(prefix)?.push(x)
      } else {
        map.set(prefix, [x])
      }
    })

    return map
  }, [process])

  const sections: Section[] = [...groups.entries()].map(([key, value]) => ({
    name: key,
    node: (
      <>
        {value.map(x => (
          <ToolAction
            key={x.id || UNDEFINED_ID}
            grapheneTool={x}
            teamId={teamId}
          />
        ))}
      </>
    ),
  }))

  return <Sidebar position='right' sections={sections} width={300} />
}

export default memo(Toolbar)
